export default class MutableContext {
    constructor(initialValue) {
        this.value = initialValue;
        this.callbacks = new Set();
        this.getValue = this.getValue.bind(this);
        this.setValue = this.setValue.bind(this);
    }
    getValue() {
        return this.value;
    }
    setValue(newValue) {
        this.value = newValue;
        this.callbacks.forEach((callback) => callback());
    }
    getValueAndSetter() {
        return [this.getValue(), this.setValue];
    }
    subscribe(callback) {
        this.callbacks.add(callback);
    }
    unsubscribe(callback) {
        this.callbacks.delete(callback);
    }
}
