import React, { createContext, useContext, useEffect, useState } from 'react';
import MutableContext from './MutableContext';
export function createMutableContext(initialValue) {
    const context = new MutableContext(initialValue);
    const reactContext = createContext(context.getValueAndSetter());
    const { Provider: ReactProvider } = reactContext;
    function MutableContextProvider(props) {
        const [value, setValue] = useState(() => context.getValueAndSetter());
        useEffect(() => {
            const cb = () => {
                setValue(context.getValueAndSetter());
            };
            context.subscribe(cb);
            return () => context.unsubscribe(cb);
        }, []);
        return React.createElement(ReactProvider, { value: value }, props.children);
    }
    function useMutableContext() {
        return useContext(reactContext);
    }
    return {
        Provider: MutableContextProvider,
        use: useMutableContext,
        getValue: context.getValue,
        setValue: context.setValue
    };
}
